/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

#ifndef _BIOH5G_READS_INTERNAL_H
#define _BIOH5G_READS_INTERNAL_H

#include "hdf5.h"
#include "biohdf_vector.h"

#define BIOH5G_SEQUENCES_NAME  "DATA_sequences"
#define BIOH5G_QUALS_NAME      "DATA_quality_values"
#define BIOH5G_IDS_NAME        "DATA_identifiers"

/* Internal reads handle */
struct _bioh5g_reads
{
    /* The path to the reads collection
     * Used for debugging and error output
     */
    char * path;

    /* The HDF5 id of the group where the reads are stored. */
    hid_t group;

    /* Reads storage handles */
    vector *sequences;
    vector *qualities;
    vector *identifiers;
};


/* Reads properties - used when creating new collections */
struct _bioh5g_reads_properties
{
    /* color or sequence space */
    bioh5g_reads_type     reads_type;

    /* Chunk size and compression level
     * Currently we use the same values for all datasets.
     */
    int64_t       chunk_size;
    compression_level  compression;
    
    /* hybrid, 1D concat or 2D fixed */
    biohdf_string_storage_scheme    sequences_scheme;
    biohdf_string_storage_scheme    ids_scheme;
    
    /* fixed length for 2D or hybrid */
    size_t                sequences_length;
    size_t                ids_length;

};


/* Internal reads iterator data */
struct _bioh5g_reads_iterator
{
    /* A reference to the collection over which this iterator will scan */
    struct _bioh5g_reads * reads;

    /* NOTE: The following indexes are used for ALL vectors */

    /* The element which will be accessed next */
    int64_t current_index;

    /* The number of elements in the data source */
    int64_t max_index;
};



#endif
