/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

#include "config.h"

#include <stdlib.h>
#include <string.h>

#include "hdf5.h"

#include "biohdf_api.h"
#include "biohdf_attribute.h"
#include "biohdf_error.h"
#include "biohdf_file.h"
#include "biohdf_file_internal.h"

/* Creates a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFcreate_attribute(biohdf_file f,
                       const char *path,
                       const char *name,
                       biohdf_attribute_data attribute)
{

    hid_t    type_id    = -1;
    hid_t    space_id   = -1;
    hid_t    attr_id    = -1;
    hid_t    group_id   = -1;
    hsize_t  dims[1];

    herr_t       hdf_error;

    /***********************************************************************/

    /* Set up */
    if(STRING_ATTRIBUTE_TYPE == attribute.atype)
    {
        type_id = H5T_NATIVE_CHAR;
        dims[0] = strlen(attribute.data.str); /* don't store the trailing \0 */
    }
    else if(INTEGER_ATTRIBUTE_TYPE == attribute.atype)
    {
        type_id = H5T_STD_I64LE;
        dims[0] = 1;
    }
    else if(DOUBLE_ATTRIBUTE_TYPE == attribute.atype)
    {
        type_id = H5T_NATIVE_DOUBLE;
        dims[0] = 1;
    }
    space_id = H5Screate_simple (1, dims, NULL);

    /* Open the group for writing */
    group_id = H5Gopen(f->file_id, path, H5P_DEFAULT);
    

    attr_id = H5Acreate(group_id, name, type_id, space_id, H5P_DEFAULT, H5P_DEFAULT);

    /* NOTE: This may have issues with the & operator and that d/i are not pointers */
    hdf_error = H5Awrite(attr_id, type_id, &(attribute.data));

    hdf_error = H5Aclose(attr_id);
    hdf_error = H5Sclose(space_id);
    hdf_error = H5Gclose(group_id);

    return BIOHDF_NO_ERROR;
}


/* Deletes a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFdelete_attribute(biohdf_file f,
                       const char *path,
                       const char *attribute_name)
{
    return BIOHDF_NO_ERROR;
}


/* Gets a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFget_attribute(biohdf_file f,
                    const char *path,
                    /*OUT*/ biohdf_attribute_data **attribute)
{
    return BIOHDF_NO_ERROR;
}

/* Get a list of all the BioHDF attributes attached to a group */
BIOHDF_API biohdf_error
BIOHDFget_list_of_attributes(biohdf_file f,
                             const char *path,
                             /*OUT*/ int *n_attributes,
                             /*OUT*/ biohdf_attribute_data **attributes)
{
    return BIOHDF_NO_ERROR;
}

/* Free a BioHDF attribute obtained from the API */
BIOHDF_API biohdf_error
BIOHDFfree_attribute(/*OUT*/ biohdf_attribute_data **attribute)
{
    ///* Free allocated attribute data */
    //if(STRING_ATTRIBUTE_TYPE == (*attribute)->atype)
    //{
    //  free((*attribute)->data);
    //}
    //free((*attribute)->name);

    //free(*attribute);
    //(*attribute) = NULL;

    return BIOHDF_NO_ERROR;
}


/* Free a list of BioHDF attributes obtained from the API */
BIOHDF_API biohdf_error
BIOHDFfree_list_of_attributes(int n_attributes,
                              /*OUT*/ biohdf_attribute_data **attributes)
{
    //int i;
    //biohdf_attribute_data *ptr = *attributes;

    //for (i = 0; i < n_attributes; i++)
    //{
    //  /* Free allocated attribute data */
    //  if(STRING_ATTRIBUTE_TYPE == ptr->atype)
    //  {
    //      free(ptr->data);
    //  }
    //  free(ptr->name);
    //  ptr++;
    //}

    //free(*attributes);
    //(*attributes) = NULL;

    return BIOHDF_NO_ERROR;
}
