/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

#ifndef _BIOHDF_ATTRIBUTE_H
#define _BIOHDF_ATTRIBUTE_H

#include "biohdf_api.h"
#include "biohdf_error.h"
#include "biohdf_file.h"


/* NOT IMPLEMENTED YET - This file is a placeholder */


/* Allowed BioHDF attribute types */
typedef enum _biohdf_attribute_type
{
    INTEGER_ATTRIBUTE_TYPE,    /* 64 bit signed */
    DOUBLE_ATTRIBUTE_TYPE,
    STRING_ATTRIBUTE_TYPE,
} biohdf_attribute_type;


/* Data structure for a BioHDF attributes */
typedef struct _biohdf_attribute_data
{
    char                   *name;
    biohdf_attribute_type  atype;
    union
    {
        int64_t i;
        double       d;
        char         *str;
    } data;
} biohdf_attribute_data;


/* Creates a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFcreate_attribute(biohdf_file f,
                       const char *path,
                       const char *name,
                       biohdf_attribute_data attribute);



/* Deletes a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFdelete_attribute(biohdf_file f,
                       const char *path,
                       const char *attribute_name);



/* Gets a BioHDF attribute in the target group. */
BIOHDF_API biohdf_error
BIOHDFget_attribute(biohdf_file f,
                    const char *path,
                    /*OUT*/ biohdf_attribute_data **attribute);


/* Get a list of all the BioHDF attributes attached to a group */
BIOHDF_API biohdf_error
BIOHDFget_list_of_attributes(biohdf_file f,
                             const char *path,
                             /*OUT*/ int *n_attributes,
                             /*OUT*/ biohdf_attribute_data **attributes);


/* Free a BioHDF attribute obtained from the API */
BIOHDF_API biohdf_error
BIOHDFfree_attribute(/*OUT*/ biohdf_attribute_data **attribute);



/* Free a list of BioHDF attributes obtained from the API */
BIOHDF_API biohdf_error
BIOHDFfree_list_of_attributes(int n_attributes,
                              /*OUT*/ biohdf_attribute_data **attributes);

#endif
