/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

/** @defgroup biohdf_file biohdf_file
 *
 *  BioHDF file manipulation functions and data structures.
 *
 *  @{
 */

#ifndef _BIOHDF_FILE_H
#define _BIOHDF_FILE_H

#include "biohdf_api.h"
#include "biohdf_error.h"



/** A BioHDF file handle. */
typedef struct _biohdf_file *biohdf_file;



/** Create a BioHDF file
 *
 *  The file handle returned by this function will be ready
 *  to accept I/O.
 *
 * @param filename The name of the BioHDF file to create.
 * @param[out] f A BioHDF file handle.
 *
 * @returns BIOHDF_NO_ERROR on success, a BioHDF error code on failure.
 */
BIOHDF_API biohdf_error 
BIOHDFcreate_biohdf_file(const char *filename,
                         /*OUT*/ biohdf_file *f);



/** Open a BioHDF file
 *
 * @param filename The name of the BioHDF file to open.
 * @param mode The file access mode (read only | read/write).
 * @param[out] f A BioHDF file handle.
 *
 * @returns BIOHDF_NO_ERROR on success, a BioHDF error code on failure.
 */
BIOHDF_API biohdf_error 
BIOHDFopen_biohdf_file(const char *filename,
                       biohdf_open_mode mode,
                       /*OUT*/ biohdf_file *f);



/** Close a BioHDF file
*
*  This function will set the file handle to NULL after freeing it.
*
* @param[in,out] f A BioHDF file handle  This will be set to NULL.
*
* @returns BIOHDF_NO_ERROR on success, a BioHDF error code on failure.
 */
BIOHDF_API biohdf_error
BIOHDFclose_biohdf_file(/*IN-OUT*/  biohdf_file *f);



/** @} */
#endif
