/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

#ifndef _BIOHDF_GROUP_INTERNAL_H
#define _BIOHDF_GROUP_INTERNAL_H

#include "hdf5.h"

#include "biohdf_api.h"
#include "biohdf_error.h"
#include "biohdf_file.h"



/*****************************************************************************
 * Internal functions                                                        *
 *****************************************************************************/



/* Get a list of groups from a BioHDF path */
BIOHDF_API biohdf_error
_parse_groups_from_path(const char *path,
                        /*OUT*/ char ***groups,
                        /*OUT*/ int *n_groups);



/* Free a list of groups */
BIOHDF_API biohdf_error
_free_groups_list(/*OUT*/ char ***groups,
                  int n_groups);



/* Create an HDF5 group or open it if it already exists. 
 * Similar to the API function, but returns an HDF5 group ID.  We don't
 * expose HDF5 types outside of the API so this is an internal function only.
 */
biohdf_error
_create_or_open_group(biohdf_file f,
                      const char *path,
                      /*OUT*/ hid_t *group_id);



#endif
