/*****************************************************************************
 * Copyright by The HDF Group                                                *
 * All rights reserved.                                                      *
 *                                                                           *
 * This file is part of BioHDF.  The full BioHDF copyright notice, including *
 * terms governing use, modification, and redistribution, is contained in    *
 * the file COPYING.  COPYING can be found at the root of the source code    *
 * distribution tree.  If you do not have access to this file, you may       *
 * request a copy from help@hdfgroup.org.                                    *
 *****************************************************************************/

/** @defgroup biohdf_utility biohdf_utility
 *  BioHDF utility functions.
 *
 *  @{
 */

#ifndef _BIOHDF_UTILITY_H
#define _BIOHDF_UTILITY_H

#include "biohdf_api.h"
#include "biohdf_error.h"



/*****************************************************************************
 * Destroy BioHDF memory (utility function)                                  *
 *****************************************************************************/



/** Free memory allocated by the BioHDF library.
 *
 * Frees memory returned via a void or char pointer from any BioHDF function.
 * The memory will be freed and set to NULL.
 * Used to avoid CRT problems on Windows and for language interop.
 *
 * @param[in,out] buffer The memory to be freed.
 * @returns BIOHDF_NO_ERROR.
 */
BIOHDF_API biohdf_error
BIOHDFfree_memory(/*IN-OUT*/ void **buffer);



/*****************************************************************************
 * Index properties                                                          *
 *****************************************************************************/

/** @name Indexing: Index Creation Properties */
/** @{*/



/** BioHDF index creation properties */
typedef struct _biohdf_index_creation_properties *biohdf_index_creation_properties;



/** Create a reads properties container */
BIOHDF_API biohdf_error
BIOHDFcreate_index_creation_properties(/*OUT*/ biohdf_index_creation_properties *props);



/** Destroy a reads properties container */
BIOHDF_API biohdf_error
BIOHDFdestroy_index_creation_properties(/*OUT*/ biohdf_index_creation_properties *props);



/** Set reads properties sequences length */
BIOHDF_API biohdf_error
BIOHDFset_index_creation_properties_max_memory_mb(biohdf_index_creation_properties props,
                                                  int64_t max_memory_to_use_mb);



/** Set reads properties sequences length */
BIOHDF_API biohdf_error
BIOHDFset_index_creation_properties_temp_path(biohdf_index_creation_properties props,
                                              char *path);



/** @} */



/** @} */
#endif
